@@ -551,7 +551,7 @@ bse_script_send_message_exec (BseProcedureClass *proc,
   const gchar *text2  = sfi_value_get_string (in_values++);
   const gchar *text3  = sfi_value_get_string (in_values++);
   const gchar *check  = sfi_value_get_string (in_values++);
-  BirnetMsgType    type  = mtype ? birnet_msg_type_lookup (mtype) : 0;
+  SfiMsgType    type  = mtype ? sfi_msg_lookup_type (mtype) : 0;
 
 #line 399 "bsejanitor.proc"
   
