@@ -261,15 +261,7 @@ bse_server_set_property (GObject      *object,
 	bse_gconfig_apply (rec);
       break;
     case PROP_WAVE_FILE:
-      if (!bse_gconfig_locked ())
-	{
-	  self->wave_file = g_strdup_stripped (g_value_get_string (value));
-	  if (!self->wave_file[0])
-	    {
-	      g_free (self->wave_file);
-	      self->wave_file = NULL;
-	    }
-	}
+      bse_server_start_recording (self, g_value_get_string (value), 0);
       break;
     case PROP_LOG_MESSAGES:
       self->log_messages = sfi_value_get_bool (value);
@@ -442,6 +434,39 @@ bse_server_find_project (BseServer   *server,
   return NULL;
 }
 
+void
+bse_server_stop_recording (BseServer *self)
+{
+  GList *node;
+  for (node = self->projects; node; node = node->next)
+    {
+      BseProject *project = node->data;
+      bse_project_stop_playback (project);
+    }
+  self->wave_seconds = 0;
+  g_free (self->wave_file);
+  self->wave_file = NULL;
+  g_object_notify (self, "wave-file");
+}
+
+void
+bse_server_start_recording (BseServer      *self,
+                            const char     *wave_file,
+                            double          n_seconds)
+{
+  if (!bse_gconfig_locked ())
+    {
+      self->wave_seconds = MAX (n_seconds, 0);
+      self->wave_file = g_strdup_stripped (wave_file ? wave_file : "");
+      if (!self->wave_file[0])
+        {
+          g_free (self->wave_file);
+          self->wave_file = NULL;
+        }
+      g_object_notify (self, "wave-file");
+    }
+}
+
 void
 bse_server_require_pcm_input (BseServer *server)
 {
@@ -449,19 +474,19 @@ bse_server_require_pcm_input (BseServer *server)
     {
       server->pcm_input_checked = TRUE;
       if (!BSE_DEVICE_READABLE (server->pcm_device))
-        birnet_msg_log (BIRNET_MSG_WARNING,
-                     BIRNET_MSG_TITLE (_("Recording Audio Input")),
-                     BIRNET_MSG_TEXT1 (_("Failed to start recording from audio device.")),
-                     BIRNET_MSG_TEXT2 (_("An audio project is in use which processes an audio input signal, but the audio device "
-                                      "has not been opened in recording mode. "
-                                      "An audio signal of silence will be used instead of a recorded signal, "
-                                      "so playback operation may produce results not actually intended "
-                                      "(such as a silent output signal).")),
-                     BIRNET_MSG_TEXT3 (_("Audio device \"%s\" is not open for input, audio driver: %s=%s"),
-                                    BSE_DEVICE (server->pcm_device)->open_device_name,
-                                    BSE_DEVICE_GET_CLASS (server->pcm_device)->driver_name,
-                                    BSE_DEVICE (server->pcm_device)->open_device_args),
-                     BIRNET_MSG_CHECK (_("Show messages about audio input problems")));
+        sfi_msg_display (SFI_MSG_WARNING,
+                         SFI_MSG_TITLE (_("Recording Audio Input")),
+                         SFI_MSG_TEXT1 (_("Failed to start recording from audio device.")),
+                         SFI_MSG_TEXT2 (_("An audio project is in use which processes an audio input signal, but the audio device "
+                                          "has not been opened in recording mode. "
+                                          "An audio signal of silence will be used instead of a recorded signal, "
+                                          "so playback operation may produce results not actually intended "
+                                          "(such as a silent output signal).")),
+                         SFI_MSG_TEXT3 (_("Audio device \"%s\" is not open for input, audio driver: %s=%s"),
+                                        BSE_DEVICE (server->pcm_device)->open_device_name,
+                                        BSE_DEVICE_GET_CLASS (server->pcm_device)->driver_name,
+                                        BSE_DEVICE (server->pcm_device)->open_device_args),
+                         SFI_MSG_CHECK (_("Show messages about audio input problems")));
     }
 }
 
@@ -502,13 +527,13 @@ server_open_pcm_device (BseServer *server,
                                                                bse_main_args->pcm_drivers,
                                                                pcm_request_callback, &pr, error ? NULL : &error);
   if (!server->pcm_device)
-    birnet_msg_log (BIRNET_MSG_ERROR,
-                 BIRNET_MSG_TITLE (_("No Audio")),
-                 BIRNET_MSG_TEXT1 (_("No available audio device was found.")),
-                 BIRNET_MSG_TEXT2 (_("No available audio device could be found and opened successfully. "
-                                   "Sorry, no fallback selection can be made for audio devices, giving up.")),
-                 BIRNET_MSG_TEXT3 (_("Failed to open PCM devices: %s"), bse_error_blurb (error)),
-                 BIRNET_MSG_CHECK (_("Show messages about PCM device selections problems")));
+    sfi_msg_display (SFI_MSG_ERROR,
+                     SFI_MSG_TITLE (_("No Audio")),
+                     SFI_MSG_TEXT1 (_("No available audio device was found.")),
+                     SFI_MSG_TEXT2 (_("No available audio device could be found and opened successfully. "
+                                      "Sorry, no fallback selection can be made for audio devices, giving up.")),
+                     SFI_MSG_TEXT3 (_("Failed to open PCM devices: %s"), bse_error_blurb (error)),
+                     SFI_MSG_CHECK (_("Show messages about PCM device selections problems")));
   server->pcm_input_checked = FALSE;
   return server->pcm_device ? BSE_ERROR_NONE : error;
 }
@@ -526,13 +551,13 @@ server_open_midi_device (BseServer *server)
       server->midi_device = (BseMidiDevice*) bse_device_open_best (BSE_TYPE_MIDI_DEVICE_NULL, TRUE, FALSE, ring, NULL, NULL, NULL);
       sfi_ring_free (ring);
       if (server->midi_device)
-        birnet_msg_log (BIRNET_MSG_WARNING,
-                     BIRNET_MSG_TITLE (_("No MIDI")),
-                     BIRNET_MSG_TEXT1 (_("MIDI input or oputput is not available.")),
-                     BIRNET_MSG_TEXT2 (_("No available MIDI device could be found and opened successfully. "
-                                      "Reverting to null device, no MIDI events will be received or sent.")),
-                     BIRNET_MSG_TEXT3 (_("Failed to open MIDI devices: %s"), bse_error_blurb (error)),
-                     BIRNET_MSG_CHECK (_("Show messages about MIDI device selections problems")));
+        sfi_msg_display (SFI_MSG_WARNING,
+                         SFI_MSG_TITLE (_("No MIDI")),
+                         SFI_MSG_TEXT1 (_("MIDI input or oputput is not available.")),
+                         SFI_MSG_TEXT2 (_("No available MIDI device could be found and opened successfully. "
+                                          "Reverting to null device, no MIDI events will be received or sent.")),
+                         SFI_MSG_TEXT3 (_("Failed to open MIDI devices: %s"), bse_error_blurb (error)),
+                         SFI_MSG_CHECK (_("Show messages about MIDI device selections problems")));
     }
   return server->midi_device ? BSE_ERROR_NONE : error;
 }
@@ -579,16 +604,19 @@ bse_server_open_devices (BseServer *self)
 	{
 	  BseErrorType error;
 	  self->pcm_writer = g_object_new (BSE_TYPE_PCM_WRITER, NULL);
-	  error = bse_pcm_writer_open (self->pcm_writer, self->wave_file, 2, bse_engine_sample_freq ());
+          const uint n_channels = 2;
+	  error = bse_pcm_writer_open (self->pcm_writer, self->wave_file,
+                                       n_channels, bse_engine_sample_freq (),
+                                       n_channels * bse_engine_sample_freq() * self->wave_seconds);
 	  if (error)
 	    {
-              birnet_msg_log (BIRNET_MSG_ERROR,
-                           BIRNET_MSG_TITLE (_("Start Disk Recording")),
-                           BIRNET_MSG_TEXT1 (_("Failed to start recording to disk.")),
-                           BIRNET_MSG_TEXT2 (_("An error occoured while opening the recording file, selecting a different "
-                                            "file might fix this situation.")),
-                           BIRNET_MSG_TEXT3 (_("Failed to open file \"%s\" for output: %s"), self->wave_file, bse_error_blurb (error)),
-                           BIRNET_MSG_CHECK (_("Show recording file errors")));
+              sfi_msg_display (SFI_MSG_ERROR,
+                               SFI_MSG_TITLE (_("Start Disk Recording")),
+                               SFI_MSG_TEXT1 (_("Failed to start recording to disk.")),
+                               SFI_MSG_TEXT2 (_("An error occoured while opening the recording file, selecting a different "
+                                                "file might fix this situation.")),
+                               SFI_MSG_TEXT3 (_("Failed to open file \"%s\" for output: %s"), self->wave_file, bse_error_blurb (error)),
+                               SFI_MSG_CHECK (_("Show recording file errors")));
 	      g_object_unref (self->pcm_writer);
 	      self->pcm_writer = NULL;
 	    }
@@ -760,17 +788,7 @@ bse_server_send_message (BseServer        *self,
   g_return_if_fail (umsg != NULL);
   g_signal_emit (self, signal_message, 0, umsg);
   if (self->log_messages)
-    {
-      BirnetMessage lmsg = { 0, };
-      lmsg.log_domain = umsg->log_domain;
-      lmsg.type = umsg->type;
-      lmsg.title = umsg->title;
-      lmsg.primary = umsg->primary;
-      lmsg.secondary = umsg->secondary;
-      lmsg.details = umsg->details;
-      lmsg.config_check = umsg->config_check;
-      birnet_msg_default_handler (&lmsg);
-    }
+    bse_message_to_default_handler (umsg);
 }
 
 void
@@ -792,8 +810,8 @@ bse_server_message (BseServer          *server,
   BseMessage umsg = { 0, };
   umsg.log_domain = (char*) log_domain;
   umsg.type = msg_type;
-  umsg.ident = (char*) birnet_msg_type_ident (msg_type);
-  umsg.label = (char*) birnet_msg_type_label (msg_type);
+  umsg.ident = (char*) sfi_msg_type_ident (msg_type);
+  umsg.label = (char*) sfi_msg_type_label (msg_type);
   umsg.title = (char*) title;
   umsg.primary = (char*) primary;
   umsg.secondary = (char*) secondary;
