@@ -123,215 +123,45 @@ can_load_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- describe-note --- */
-static void
-describe_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 112 "bseserver.proc"
- {
-#line 114 "bseserver.proc"
-  *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = bse_pspec_note_simple ("note", "Note", NULL, SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = bse_param_spec_fine_tune ("fine_tune", "Fine Tune", NULL);
-  *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
-}
-#line 121 "bseserver.proc"
- }
-static BseErrorType
-#line 121 "bseserver.proc"
-describe_note_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 124 "bseserver.proc"
-{
-#line 125 "bseserver.proc"
-  
-  BseServer *server	= bse_value_get_object (in_values++);
-  gint       note	= sfi_value_get_int (in_values++);
-  gint       fine_tune	= sfi_value_get_int (in_values++);
-  
-#line 130 "bseserver.proc"
-  
-  if (!BSE_IS_SERVER (server))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-#line 134 "bseserver.proc"
-  
-  bse_value_take_boxed (out_values++, bse_note_description (note, fine_tune));
-  
-  return BSE_ERROR_NONE;
-}
-
-/* --- note-from-freq --- */
-static void
-note_from_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 140 "bseserver.proc"
- {
-#line 142 "bseserver.proc"
-  *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = sfi_pspec_real ("freq", "Frequency", NULL,
-			  BSE_KAMMER_FREQUENCY,
-			  0, BSE_MAX_FREQUENCY,
-			  10.0, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
-}
-#line 151 "bseserver.proc"
- }
-static BseErrorType
-#line 151 "bseserver.proc"
-note_from_freq_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 154 "bseserver.proc"
-{
-#line 155 "bseserver.proc"
-  
-  BseServer *server	= bse_value_get_object (in_values++);
-  gfloat     freq	= sfi_value_get_real (in_values++);
-  gint note;
-  
-#line 160 "bseserver.proc"
-  
-  if (!BSE_IS_SERVER (server))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-#line 164 "bseserver.proc"
-  
-  note = bse_note_from_freq (freq);
-  bse_value_take_boxed (out_values++, bse_note_description (note, 0));
-  
-  return BSE_ERROR_NONE;
-}
-
-/* --- note-from-string --- */
-static void
-note_from_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 171 "bseserver.proc"
- {
-#line 173 "bseserver.proc"
-  *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = sfi_pspec_string ("name", "Name", NULL,
-			    "", SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
-}
-#line 180 "bseserver.proc"
- }
-static BseErrorType
-#line 180 "bseserver.proc"
-note_from_string_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 183 "bseserver.proc"
-{
-#line 184 "bseserver.proc"
-  
-  BseServer *server	= bse_value_get_object (in_values++);
-  gchar     *name     	= sfi_value_get_string (in_values++);
-  gint note;
-  
-#line 189 "bseserver.proc"
-  
-  if (!BSE_IS_SERVER (server) || !name)
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-#line 193 "bseserver.proc"
-  
-  note = bse_note_from_string (name);
-  bse_value_take_boxed (out_values++, bse_note_description (note, 0));
-  
-  return BSE_ERROR_NONE;
-}
-
-/* --- construct-note --- */
-static void
-construct_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 200 "bseserver.proc"
- {
-#line 202 "bseserver.proc"
-  *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
-				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = sfi_pspec_int ("semitone", NULL, NULL,
-			 9, 0, 11, 1,
-			 SFI_PARAM_STANDARD);
-  *(in_pspecs++)    = bse_param_spec_octave ("octave", NULL, NULL);
-  *(in_pspecs++)    = bse_param_spec_fine_tune ("fine_tune", "Fine Tune", NULL);
-  *(out_pspecs++)   = bse_param_spec_boxed ("note-description", "Note Description", NULL,
-                                BSE_TYPE_NOTE_DESCRIPTION, SFI_PARAM_STANDARD);
-}
-#line 212 "bseserver.proc"
- }
-static BseErrorType
-#line 212 "bseserver.proc"
-construct_note_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 215 "bseserver.proc"
-{
-#line 216 "bseserver.proc"
-  
-  BseServer *server	= bse_value_get_object (in_values++);
-  guint      semitone	= sfi_value_get_int (in_values++);
-  gint       octave	= sfi_value_get_int (in_values++);
-  gint       fine_tune	= sfi_value_get_int (in_values++);
-  gint note;
-  
-#line 223 "bseserver.proc"
-  
-  if (!BSE_IS_SERVER (server))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-#line 227 "bseserver.proc"
-  
-  note = BSE_NOTE_GENERIC (octave, semitone);
-  bse_value_take_boxed (out_values++, bse_note_description (note, fine_tune));
-  
-  return BSE_ERROR_NONE;
-}
-
 /* --- n-scripts --- */
 static void
 n_scripts_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 234 "bseserver.proc"
+#line 112 "bseserver.proc"
  {
-#line 236 "bseserver.proc"
+#line 114 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_connections", NULL, "Number of Connections",
 			 0, 0, G_MAXINT, 1,
 			 SFI_PARAM_STANDARD);
 }
-#line 242 "bseserver.proc"
+#line 120 "bseserver.proc"
  }
 static BseErrorType
-#line 242 "bseserver.proc"
+#line 120 "bseserver.proc"
 n_scripts_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 245 "bseserver.proc"
+#line 123 "bseserver.proc"
 {
-#line 246 "bseserver.proc"
+#line 124 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   GSList *slist;
   guint n_scripts = 0;
   
-#line 251 "bseserver.proc"
+#line 129 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 255 "bseserver.proc"
+#line 133 "bseserver.proc"
   
   for (slist = server->children; slist; slist = slist->next)
     if (BSE_IS_JANITOR (slist->data))
       n_scripts++;
   
-#line 260 "bseserver.proc"
+#line 138 "bseserver.proc"
   
   sfi_value_set_int (out_values++, n_scripts);
   
@@ -341,33 +171,33 @@ n_scripts_exec (BseProcedureClass *proc,
 /* --- preferences-locked --- */
 static void
 preferences_locked_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 266 "bseserver.proc"
+#line 144 "bseserver.proc"
  {
-#line 268 "bseserver.proc"
+#line 146 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("locked", NULL, NULL,
 			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 273 "bseserver.proc"
+#line 151 "bseserver.proc"
  }
 static BseErrorType
-#line 273 "bseserver.proc"
+#line 151 "bseserver.proc"
 preferences_locked_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 276 "bseserver.proc"
+#line 154 "bseserver.proc"
 {
-#line 277 "bseserver.proc"
+#line 155 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   
-#line 280 "bseserver.proc"
+#line 158 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 284 "bseserver.proc"
+#line 162 "bseserver.proc"
   
   sfi_value_set_int (out_values++, bse_gconfig_locked ());
   
@@ -421,29 +251,29 @@ register_scripts (gpointer data)
 /* --- register-scripts --- */
 static void
 register_scripts_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 334 "bseserver.proc"
+#line 212 "bseserver.proc"
  {
-#line 336 "bseserver.proc"
+#line 214 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 339 "bseserver.proc"
+#line 217 "bseserver.proc"
  }
 static BseErrorType
-#line 339 "bseserver.proc"
+#line 217 "bseserver.proc"
 register_scripts_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 342 "bseserver.proc"
+#line 220 "bseserver.proc"
 {
   static gboolean registration_done = FALSE;
-#line 344 "bseserver.proc"
+#line 222 "bseserver.proc"
   
   BseServer *server	       = bse_value_get_object (in_values++);
   ScriptRegistration *scr_list = NULL;
   SfiRing *ring;
   
-#line 349 "bseserver.proc"
+#line 227 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -497,28 +327,28 @@ register_core_plugins (gpointer data)
 /* --- register-core-plugins --- */
 static void
 register_core_plugins_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 399 "bseserver.proc"
+#line 277 "bseserver.proc"
  {
-#line 401 "bseserver.proc"
+#line 279 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 404 "bseserver.proc"
+#line 282 "bseserver.proc"
  }
 static BseErrorType
-#line 404 "bseserver.proc"
+#line 282 "bseserver.proc"
 register_core_plugins_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 407 "bseserver.proc"
+#line 285 "bseserver.proc"
 {
   static gboolean registration_done = FALSE;
-#line 409 "bseserver.proc"
+#line 287 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   SfiRing *ring;
   
-#line 413 "bseserver.proc"
+#line 291 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -547,7 +377,7 @@ register_ladspa_plugins (gpointer data)
   
   if (g_object_get_data (server, "plugin-registration-queue"))
     {
-#line 441 "bseserver.proc"
+#line 319 "bseserver.proc"
       
       return TRUE;
     }
@@ -571,28 +401,28 @@ register_ladspa_plugins (gpointer data)
 /* --- register-ladspa-plugins --- */
 static void
 register_ladspa_plugins_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 461 "bseserver.proc"
+#line 339 "bseserver.proc"
  {
-#line 463 "bseserver.proc"
+#line 341 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 466 "bseserver.proc"
+#line 344 "bseserver.proc"
  }
 static BseErrorType
-#line 466 "bseserver.proc"
+#line 344 "bseserver.proc"
 register_ladspa_plugins_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 469 "bseserver.proc"
+#line 347 "bseserver.proc"
 {
   static gboolean registration_done = FALSE;
-#line 471 "bseserver.proc"
+#line 349 "bseserver.proc"
   
   BseServer *server	= bse_value_get_object (in_values++);
   SfiRing *ring;
   
-#line 475 "bseserver.proc"
+#line 353 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -620,22 +450,22 @@ register_ladspa_plugins_exec (BseProcedureClass *proc,
 /* --- save-preferences --- */
 static void
 save_preferences_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 499 "bseserver.proc"
+#line 377 "bseserver.proc"
  {
-#line 501 "bseserver.proc"
+#line 379 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
 }
-#line 504 "bseserver.proc"
+#line 382 "bseserver.proc"
  }
 static BseErrorType
-#line 504 "bseserver.proc"
+#line 382 "bseserver.proc"
 save_preferences_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 507 "bseserver.proc"
+#line 385 "bseserver.proc"
 {
-#line 508 "bseserver.proc"
+#line 386 "bseserver.proc"
   
   BseServer *server = bse_value_get_object (in_values++);
   SfiWStore *wstore;
@@ -644,14 +474,14 @@ save_preferences_exec (BseProcedureClass *proc,
   SfiRec *rec;
   gint fd;
   
-#line 516 "bseserver.proc"
+#line 394 "bseserver.proc"
   
   if (!BSE_IS_SERVER (server))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
   file_name = g_strconcat (g_get_home_dir (), "/.bserc", NULL);
   fd = open (file_name,
-#line 522 "bseserver.proc"
+#line 400 "bseserver.proc"
 	     O_WRONLY | O_CREAT | O_TRUNC, 
 	     0666);
   g_free (file_name);
@@ -661,7 +491,7 @@ save_preferences_exec (BseProcedureClass *proc,
   wstore = sfi_wstore_new ();
   sfi_wstore_printf (wstore, "; rc-file for BSE v%s\n", BSE_VERSION);
   
-#line 531 "bseserver.proc"
+#line 409 "bseserver.proc"
   
   sfi_wstore_puts (wstore, "\n; BseGConfig Dump\n");
   rec = bse_gconfig_to_rec (bse_global_config);
@@ -671,7 +501,7 @@ save_preferences_exec (BseProcedureClass *proc,
   sfi_rec_unref (rec);
   sfi_wstore_puts (wstore, "\n");
   
-#line 540 "bseserver.proc"
+#line 418 "bseserver.proc"
   
   sfi_wstore_flush_fd (wstore, fd);
   sfi_wstore_destroy (wstore);
@@ -680,24 +510,60 @@ save_preferences_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
+/* --- start-recording --- */
+static void
+start_recording_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 426 "bseserver.proc"
+ {
+#line 428 "bseserver.proc"
+  *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_string ("wave-file", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_real ("n_seconds", NULL, "Maximum number of recorded seconds",
+			  0, 0, SFI_MAXNUM, 60, SFI_PARAM_STANDARD);
+}
+#line 434 "bseserver.proc"
+ }
+static BseErrorType
+#line 434 "bseserver.proc"
+start_recording_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 437 "bseserver.proc"
+{
+#line 438 "bseserver.proc"
+  
+  BseServer *server     = bse_value_get_object (in_values++);
+  const char *wave_file = g_value_get_string (in_values++);
+  double n_seconds      = g_value_get_double (in_values++);
+
+#line 443 "bseserver.proc"
+  
+  if (!BSE_IS_SERVER (server))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+
+  bse_server_start_recording (server, wave_file, n_seconds);
+  return BSE_ERROR_NONE;
+}
+
 /* --- get-version --- */
 static void
 get_version_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 548 "bseserver.proc"
+#line 451 "bseserver.proc"
  {
-#line 550 "bseserver.proc"
+#line 453 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 554 "bseserver.proc"
+#line 457 "bseserver.proc"
  }
 static BseErrorType
-#line 554 "bseserver.proc"
+#line 457 "bseserver.proc"
 get_version_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 557 "bseserver.proc"
+#line 460 "bseserver.proc"
 {
   sfi_value_set_string (out_values++, BSE_VERSION);
   return BSE_ERROR_NONE;
@@ -706,21 +572,21 @@ get_version_exec (BseProcedureClass *proc,
 /* --- get-demo-path --- */
 static void
 get_demo_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 562 "bseserver.proc"
+#line 465 "bseserver.proc"
  {
-#line 564 "bseserver.proc"
+#line 467 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 568 "bseserver.proc"
+#line 471 "bseserver.proc"
  }
 static BseErrorType
-#line 568 "bseserver.proc"
+#line 471 "bseserver.proc"
 get_demo_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 571 "bseserver.proc"
+#line 474 "bseserver.proc"
 {
   sfi_value_set_string (out_values++, BSE_PATH_DEMOS);
   return BSE_ERROR_NONE;
@@ -729,21 +595,21 @@ get_demo_path_exec (BseProcedureClass *proc,
 /* --- get-sample-path --- */
 static void
 get_sample_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 576 "bseserver.proc"
+#line 479 "bseserver.proc"
  {
-#line 578 "bseserver.proc"
+#line 481 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 582 "bseserver.proc"
+#line 485 "bseserver.proc"
  }
 static BseErrorType
-#line 582 "bseserver.proc"
+#line 485 "bseserver.proc"
 get_sample_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 585 "bseserver.proc"
+#line 488 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_SAMPLES, BSE_GCONFIG (sample_path), NULL));
   return BSE_ERROR_NONE;
@@ -752,21 +618,21 @@ get_sample_path_exec (BseProcedureClass *proc,
 /* --- get-custom-effect-dir --- */
 static void
 get_custom_effect_dir_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 590 "bseserver.proc"
+#line 493 "bseserver.proc"
  {
-#line 592 "bseserver.proc"
+#line 495 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 596 "bseserver.proc"
+#line 499 "bseserver.proc"
  }
 static BseErrorType
-#line 596 "bseserver.proc"
+#line 499 "bseserver.proc"
 get_custom_effect_dir_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 599 "bseserver.proc"
+#line 502 "bseserver.proc"
 {
   gchar **dirs = g_strsplit (BSE_GCONFIG (effect_path), G_SEARCHPATH_SEPARATOR_S, 2);
   sfi_value_set_string (out_values++, dirs[0]);
@@ -777,21 +643,21 @@ get_custom_effect_dir_exec (BseProcedureClass *proc,
 /* --- get-effect-path --- */
 static void
 get_effect_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 606 "bseserver.proc"
+#line 509 "bseserver.proc"
  {
-#line 608 "bseserver.proc"
+#line 511 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 612 "bseserver.proc"
+#line 515 "bseserver.proc"
  }
 static BseErrorType
-#line 612 "bseserver.proc"
+#line 515 "bseserver.proc"
 get_effect_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 615 "bseserver.proc"
+#line 518 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_EFFECTS, BSE_GCONFIG (effect_path), NULL));
   return BSE_ERROR_NONE;
@@ -800,21 +666,21 @@ get_effect_path_exec (BseProcedureClass *proc,
 /* --- get-custom-instrument-dir --- */
 static void
 get_custom_instrument_dir_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 620 "bseserver.proc"
+#line 523 "bseserver.proc"
  {
-#line 622 "bseserver.proc"
+#line 525 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("directory", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 626 "bseserver.proc"
+#line 529 "bseserver.proc"
  }
 static BseErrorType
-#line 626 "bseserver.proc"
+#line 529 "bseserver.proc"
 get_custom_instrument_dir_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 629 "bseserver.proc"
+#line 532 "bseserver.proc"
 {
   gchar **dirs = g_strsplit (BSE_GCONFIG (instrument_path), G_SEARCHPATH_SEPARATOR_S, 2);
   sfi_value_set_string (out_values++, dirs[0]);
@@ -825,21 +691,21 @@ get_custom_instrument_dir_exec (BseProcedureClass *proc,
 /* --- get-instrument-path --- */
 static void
 get_instrument_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 636 "bseserver.proc"
+#line 539 "bseserver.proc"
  {
-#line 638 "bseserver.proc"
+#line 541 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 642 "bseserver.proc"
+#line 545 "bseserver.proc"
  }
 static BseErrorType
-#line 642 "bseserver.proc"
+#line 545 "bseserver.proc"
 get_instrument_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 645 "bseserver.proc"
+#line 548 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_INSTRUMENTS, BSE_GCONFIG (instrument_path), NULL));
   return BSE_ERROR_NONE;
@@ -848,21 +714,21 @@ get_instrument_path_exec (BseProcedureClass *proc,
 /* --- get-script-path --- */
 static void
 get_script_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 650 "bseserver.proc"
+#line 553 "bseserver.proc"
  {
-#line 652 "bseserver.proc"
+#line 555 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 656 "bseserver.proc"
+#line 559 "bseserver.proc"
  }
 static BseErrorType
-#line 656 "bseserver.proc"
+#line 559 "bseserver.proc"
 get_script_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 659 "bseserver.proc"
+#line 562 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_SCRIPTS, BSE_GCONFIG (script_path), NULL));
   return BSE_ERROR_NONE;
@@ -871,21 +737,21 @@ get_script_path_exec (BseProcedureClass *proc,
 /* --- get-plugin-path --- */
 static void
 get_plugin_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 664 "bseserver.proc"
+#line 567 "bseserver.proc"
  {
-#line 666 "bseserver.proc"
+#line 569 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 670 "bseserver.proc"
+#line 573 "bseserver.proc"
  }
 static BseErrorType
-#line 670 "bseserver.proc"
+#line 573 "bseserver.proc"
 get_plugin_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 673 "bseserver.proc"
+#line 576 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_PLUGINS, BSE_GCONFIG (plugin_path), NULL));
   return BSE_ERROR_NONE;
@@ -894,46 +760,78 @@ get_plugin_path_exec (BseProcedureClass *proc,
 /* --- get-ladspa-path --- */
 static void
 get_ladspa_path_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 678 "bseserver.proc"
+#line 581 "bseserver.proc"
  {
-#line 680 "bseserver.proc"
+#line 583 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("path", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 684 "bseserver.proc"
+#line 587 "bseserver.proc"
  }
 static BseErrorType
-#line 684 "bseserver.proc"
+#line 587 "bseserver.proc"
 get_ladspa_path_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 687 "bseserver.proc"
+#line 590 "bseserver.proc"
 {
   sfi_value_take_string (out_values++, g_path_concat (BSE_PATH_LADSPA, BSE_GCONFIG (ladspa_path), NULL));
   return BSE_ERROR_NONE;
 }
 
+#include "gslvorbis-enc.h"
+
+/* --- get-vorbis-version --- */
+static void
+get_vorbis_version_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 597 "bseserver.proc"
+ {
+#line 599 "bseserver.proc"
+  *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
+				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+}
+#line 603 "bseserver.proc"
+ }
+static BseErrorType
+#line 603 "bseserver.proc"
+get_vorbis_version_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 606 "bseserver.proc"
+{
+  gchar *v = gsl_vorbis_encoder_version();
+  if (v && strncmp (v, "Xiphophorus libVorbis", 21) == 0)
+    sfi_value_take_string (out_values++, g_strconcat ("Ogg/Vorbis", v + 21, NULL));
+  else if (v && strncmp (v, "Xiph.Org libVorbis", 18) == 0)
+    sfi_value_take_string (out_values++, g_strconcat ("Ogg/Vorbis", v + 18, NULL));
+  else if (v)
+    sfi_value_take_string (out_values++, g_strconcat ("Ogg/Vorbis ", v, NULL));
+  g_free (v);
+  return BSE_ERROR_NONE;
+}
+
 #include "gsldatahandle-mad.h"
 
 /* --- get-mp3-version --- */
 static void
 get_mp3_version_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 694 "bseserver.proc"
+#line 620 "bseserver.proc"
  {
-#line 696 "bseserver.proc"
+#line 622 "bseserver.proc"
   *(in_pspecs++) = bse_param_spec_object ("server", "Server", NULL,
 				 BSE_TYPE_SERVER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("version", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 }
-#line 700 "bseserver.proc"
+#line 626 "bseserver.proc"
  }
 static BseErrorType
-#line 700 "bseserver.proc"
+#line 626 "bseserver.proc"
 get_mp3_version_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 703 "bseserver.proc"
+#line 629 "bseserver.proc"
 {
   const gchar *c = gsl_data_handle_mad_version ();
   if (c)
@@ -981,92 +879,16 @@ static BseExportNodeProc __enode_can_load = {
   0, can_load_setup, can_load_exec, 
 };
 static void
-__enode_describe_note__fill_strings (BseExportStrings *es)
+__enode_n_scripts__fill_strings (BseExportStrings *es)
 {
-  es->blurb = "Describe a note, providing information about its octave, semitone, frequency, etc.";
+  es->blurb = "Return the number of scripts currently running on this server.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
   es->line = 113;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
-static BseExportNodeProc __enode_describe_note = {
-  { (BseExportNode*) &__enode_can_load, BSE_EXPORT_NODE_PROC,
-    "BseServer+describe-note", 
-    NULL,
-    "/Methods/BseServer/General/Describe Note",
-    NULL,
-    __enode_describe_note__fill_strings,
-  },
-  0, describe_note_setup, describe_note_exec, 
-};
-static void
-__enode_note_from_freq__fill_strings (BseExportStrings *es)
-{
-  es->blurb = "Describe a note, given its frequency.";
-  es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 141;
-  es->authors = "Tim Janik <timj@gtk.org>";
-  es->license = "GNU General Public License";
-}
-static BseExportNodeProc __enode_note_from_freq = {
-  { (BseExportNode*) &__enode_describe_note, BSE_EXPORT_NODE_PROC,
-    "BseServer+note-from-freq", 
-    NULL,
-    "/Methods/BseServer/General/Note From Freq",
-    NULL,
-    __enode_note_from_freq__fill_strings,
-  },
-  0, note_from_freq_setup, note_from_freq_exec, 
-};
-static void
-__enode_note_from_string__fill_strings (BseExportStrings *es)
-{
-  es->blurb = "Describe a note, given its name and octave offset.";
-  es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 172;
-  es->authors = "Tim Janik <timj@gtk.org>";
-  es->license = "GNU General Public License";
-}
-static BseExportNodeProc __enode_note_from_string = {
-  { (BseExportNode*) &__enode_note_from_freq, BSE_EXPORT_NODE_PROC,
-    "BseServer+note-from-string", 
-    NULL,
-    "/Methods/BseServer/General/Note From String",
-    NULL,
-    __enode_note_from_string__fill_strings,
-  },
-  0, note_from_string_setup, note_from_string_exec, 
-};
-static void
-__enode_construct_note__fill_strings (BseExportStrings *es)
-{
-  es->blurb = "Describe a note, given its semitone, octave and fine tune.";
-  es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 201;
-  es->authors = "Tim Janik <timj@gtk.org>";
-  es->license = "GNU General Public License";
-}
-static BseExportNodeProc __enode_construct_note = {
-  { (BseExportNode*) &__enode_note_from_string, BSE_EXPORT_NODE_PROC,
-    "BseServer+construct-note", 
-    NULL,
-    "/Methods/BseServer/General/Construct Note",
-    NULL,
-    __enode_construct_note__fill_strings,
-  },
-  0, construct_note_setup, construct_note_exec, 
-};
-static void
-__enode_n_scripts__fill_strings (BseExportStrings *es)
-{
-  es->blurb = "Return the number of scripts currently running on this server.";
-  es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 235;
-  es->authors = "Tim Janik <timj@gtk.org>";
-  es->license = "GNU General Public License";
-}
 static BseExportNodeProc __enode_n_scripts = {
-  { (BseExportNode*) &__enode_construct_note, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_can_load, BSE_EXPORT_NODE_PROC,
     "BseServer+n-scripts", 
     NULL,
     "/Methods/BseServer/General/N Scripts",
@@ -1080,7 +902,7 @@ __enode_preferences_locked__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Returns whether the bse-preferences property is currently locked against modifications or not.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 267;
+  es->line = 145;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1099,7 +921,7 @@ __enode_register_scripts__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Register external scripts.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 335;
+  es->line = 213;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1118,7 +940,7 @@ __enode_register_core_plugins__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Register core plugins.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 400;
+  es->line = 278;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1137,7 +959,7 @@ __enode_register_ladspa_plugins__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Register LADSPA (Linux Audio Developer's Simple Plugin API) plugins.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 462;
+  es->line = 340;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1156,7 +978,7 @@ __enode_save_preferences__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Request the bse-preferences property to be saved into BSE's configuration file.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 500;
+  es->line = 378;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1171,16 +993,35 @@ static BseExportNodeProc __enode_save_preferences = {
   0, save_preferences_setup, save_preferences_exec, 
 };
 static void
+__enode_start_recording__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Start recording to a WAV file.";
+  es->file = "/opt/src/beast/bse/bseserver.proc";
+  es->line = 427;
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
+static BseExportNodeProc __enode_start_recording = {
+  { (BseExportNode*) &__enode_save_preferences, BSE_EXPORT_NODE_PROC,
+    "BseServer+start-recording", 
+    NULL,
+    "/Methods/BseServer/General/Start Recording",
+    NULL,
+    __enode_start_recording__fill_strings,
+  },
+  0, start_recording_setup, start_recording_exec, 
+};
+static void
 __enode_get_version__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve BSE version.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 549;
+  es->line = 452;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
 static BseExportNodeProc __enode_get_version = {
-  { (BseExportNode*) &__enode_save_preferences, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_start_recording, BSE_EXPORT_NODE_PROC,
     "BseServer+get-version", 
     NULL,
     "/Methods/BseServer/General/Get Version",
@@ -1194,7 +1035,7 @@ __enode_get_demo_path__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve demo search path.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 563;
+  es->line = 466;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1213,7 +1054,7 @@ __enode_get_sample_path__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve sample search path.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 577;
+  es->line = 480;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1232,7 +1073,7 @@ __enode_get_custom_effect_dir__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve user specific effects directory.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 591;
+  es->line = 494;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1251,7 +1092,7 @@ __enode_get_effect_path__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve effect search path.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 607;
+  es->line = 510;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1270,7 +1111,7 @@ __enode_get_custom_instrument_dir__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve user specific instruments directory.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 621;
+  es->line = 524;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1289,7 +1130,7 @@ __enode_get_instrument_path__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve instrument search path.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 637;
+  es->line = 540;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1308,7 +1149,7 @@ __enode_get_script_path__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve script search path.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 651;
+  es->line = 554;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1327,7 +1168,7 @@ __enode_get_plugin_path__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve plugin search path.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 665;
+  es->line = 568;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1346,7 +1187,7 @@ __enode_get_ladspa_path__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve ladspa search path.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 679;
+  es->line = 582;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
@@ -1361,16 +1202,35 @@ static BseExportNodeProc __enode_get_ladspa_path = {
   0, get_ladspa_path_setup, get_ladspa_path_exec, 
 };
 static void
+__enode_get_vorbis_version__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve BSE Vorbis handler version.";
+  es->file = "/opt/src/beast/bse/bseserver.proc";
+  es->line = 598;
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
+static BseExportNodeProc __enode_get_vorbis_version = {
+  { (BseExportNode*) &__enode_get_ladspa_path, BSE_EXPORT_NODE_PROC,
+    "BseServer+get-vorbis-version", 
+    NULL,
+    "/Methods/BseServer/General/Get Vorbis Version",
+    NULL,
+    __enode_get_vorbis_version__fill_strings,
+  },
+  0, get_vorbis_version_setup, get_vorbis_version_exec, 
+};
+static void
 __enode_get_mp3_version__fill_strings (BseExportStrings *es)
 {
   es->blurb = "Retrieve BSE MP3 handler version.";
   es->file = "/opt/src/beast/bse/bseserver.proc";
-  es->line = 695;
+  es->line = 621;
   es->authors = "Tim Janik <timj@gtk.org>";
   es->license = "GNU General Public License";
 }
 static BseExportNodeProc __enode_get_mp3_version = {
-  { (BseExportNode*) &__enode_get_ladspa_path, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_get_vorbis_version, BSE_EXPORT_NODE_PROC,
     "BseServer+get-mp3-version", 
     NULL,
     "/Methods/BseServer/General/Get Mp3 Version",
