@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bsesong.h"
-
+#include "bsemathsignal.h"
 #include "bsetrack.h"
 #include "bsepart.h"
 #include "bsebus.h"
@@ -35,6 +35,7 @@
 enum
 {
   PROP_0,
+  PROP_MUSICAL_TUNING,
   PROP_TPQN,
   PROP_NUMERATOR,
   PROP_DENOMINATOR,
@@ -166,6 +167,15 @@ bse_song_set_property (GObject      *object,
       gboolean vbool;
       SfiInt vint;
       SfiRing *ring;
+    case PROP_MUSICAL_TUNING:
+      if (!BSE_SOURCE_PREPARED (self))
+        {
+          self->musical_tuning = g_value_get_enum (value);
+          SfiRing *ring;
+          for (ring = self->parts; ring; ring = sfi_ring_walk (ring, self->parts))
+            bse_part_set_semitone_table (ring->data, bse_semitone_table_from_tuning (self->musical_tuning));
+        }
+      break;
     case PROP_BPM:
       self->bpm = sfi_value_get_real (value);
       bse_song_update_tpsi_SL (self);
@@ -273,6 +283,9 @@ bse_song_get_property (GObject     *object,
   BseSong *self = BSE_SONG (object);
   switch (param_id)
     {
+    case PROP_MUSICAL_TUNING:
+      g_value_set_enum (value, self->musical_tuning);
+      break;
     case PROP_BPM:
       sfi_value_set_real (value, self->bpm);
       break;
@@ -489,7 +502,8 @@ bse_song_prepare (BseSource *source)
   BseSong *self = BSE_SONG (source);
 
   bse_object_lock (BSE_OBJECT (self));
-  
+  self->sequencer_underrun_detected_SL = FALSE;
+
   /* chain parent class' handler */
   BSE_SOURCE_CLASS (parent_class)->prepare (source);
 
@@ -591,6 +605,8 @@ bse_song_init (BseSong *self)
   BSE_OBJECT_UNSET_FLAGS (self, BSE_SNET_FLAG_USER_SYNTH);
   BSE_OBJECT_SET_FLAGS (self, BSE_SUPER_FLAG_NEEDS_CONTEXT);
 
+  self->musical_tuning = BSE_MUSICAL_TUNING_12_TET;
+
   self->tpqn = timing.tpqn;
   self->numerator = timing.numerator;
   self->denominator = timing.denominator;
@@ -728,6 +744,16 @@ bse_song_class_init (BseSongClass *class)
 
   bse_song_timing_get_default (&timing);
 
+  bse_object_class_add_param (object_class, _("Tuning"),
+			      PROP_MUSICAL_TUNING,
+                              bse_param_spec_enum ("musical_tuning", _("Musical Tuning"),
+                                                   _("The tuning system which specifies the tones or pitches to be used. "
+                                                     "Due to the psychoacoustic properties of tones, various pitch combinations can "
+                                                     "sound \"natural\" or \"pleasing\" when used in combination, the musical "
+                                                     "tuning system defines the number and spacing of frequency values applied."),
+                                                   BSE_MUSICAL_TUNING_12_TET, BSE_TYPE_MUSICAL_TUNING_TYPE,
+                                                   SFI_PARAM_STANDARD ":unprepared:skip-default"));
+
   bse_object_class_add_param (object_class, _("Timing"),
 			      PROP_TPQN,
 			      sfi_pspec_int ("tpqn", _("Ticks"), _("Number of ticks per quarter note"),
