@@ -43,6 +43,8 @@ enum
   PARAM_0,
   PARAM_BASE_FREQ,
   PARAM_BASE_NOTE,
+  PARAM_TRANSPOSE,
+  PARAM_FINE_TUNE,
   PARAM_TRIGGER_VEL,
   PARAM_TRIGGER_HIT,
   PARAM_NOTE_DECAY,
@@ -63,6 +65,7 @@ static void	   dav_xtal_strings_get_property     (GObject              *object,
 						      guint                 param_id,
 						      GValue               *value,
 						      GParamSpec           *pspec);
+static void        dav_xtal_prepare                  (BseSource            *source);
 static void	   dav_xtal_strings_context_create   (BseSource		   *source,
 						      guint		    context_handle,
 						      BseTrans		   *trans);
@@ -78,7 +81,7 @@ BSE_REGISTER_OBJECT (DavXtalStrings, BseSource, "/Modules/Audio Sources/XtalStri
                      "until 2004 requires a license from Stanford University.",
                      strings_icon,
                      dav_xtal_strings_class_init, NULL, dav_xtal_strings_init);
-BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
+BSE_DEFINE_EXPORTS ();
 
 
 /* --- variables --- */
@@ -99,42 +102,56 @@ dav_xtal_strings_class_init (DavXtalStringsClass *class)
   gobject_class->set_property = dav_xtal_strings_set_property;
   gobject_class->get_property = dav_xtal_strings_get_property;
   
+  source_class->prepare = dav_xtal_prepare;
   source_class->context_create = dav_xtal_strings_context_create;
   
-  bse_object_class_add_param (object_class, "Frequency",
+  bse_object_class_add_param (object_class, _("Frequency"),
 			      PARAM_BASE_FREQ,
-			      bse_param_spec_freq ("base_freq", "Frequency", NULL,
+			      bse_param_spec_freq ("base_freq", _("Frequency"),
+                                                   _("String oscillation frequency in Hertz"),
 						   BSE_KAMMER_FREQUENCY, BSE_MIN_OSC_FREQUENCY, BSE_MAX_OSC_FREQUENCY,
 						   SFI_PARAM_STANDARD ":dial"));
-  bse_object_class_add_param (object_class, "Frequency",
+  bse_object_class_add_param (object_class, _("Frequency"),
 			      PARAM_BASE_NOTE,
-			      bse_pspec_note_simple ("base_note", "Note", NULL, SFI_PARAM_GUI));
-  bse_object_class_add_param (object_class, "Trigger", PARAM_TRIGGER_VEL,
-			      sfi_pspec_real ("trigger_vel", "Trigger Velocity [%]",
-                                              "Velocity of the string pluck",
+			      bse_pspec_note_simple ("base_note", _("Note"),
+                                                     _("String oscillation frequency as note, converted to Hertz according to the current musical tuning"),
+                                                     SFI_PARAM_GUI));
+  bse_object_class_add_param (object_class, _("Frequency"),
+			      PARAM_TRANSPOSE,
+			      sfi_pspec_int ("transpose", _("Transpose"), _("Transposition of the frequency in semitones"),
+					     0, BSE_MIN_TRANSPOSE, BSE_MAX_TRANSPOSE, 12,
+					     SFI_PARAM_STANDARD ":f:dial:skip-default"));
+  bse_object_class_add_param (object_class, _("Frequency"),
+			      PARAM_FINE_TUNE,
+			      sfi_pspec_int ("fine_tune", _("Fine Tune"), _("Amount of detuning in cent (hundredth part of a semitone)"),
+					     0, BSE_MIN_FINE_TUNE, BSE_MAX_FINE_TUNE, 10,
+					     SFI_PARAM_STANDARD ":f:dial:skip-default"));
+  bse_object_class_add_param (object_class, _("Trigger"), PARAM_TRIGGER_VEL,
+			      sfi_pspec_real ("trigger_vel", _("Trigger Velocity [%]"),
+                                              _("Velocity of the string pluck"),
                                               100.0,  0.0, 100.0, 1,
                                               SFI_PARAM_GUI ":scale"));
-  bse_object_class_add_param (object_class, "Trigger", PARAM_TRIGGER_HIT,
-			      sfi_pspec_bool ("trigger_pulse", "Trigger Hit", "Pluck the string",
+  bse_object_class_add_param (object_class, _("Trigger"), PARAM_TRIGGER_HIT,
+			      sfi_pspec_bool ("trigger_pulse", _("Trigger Hit"), _("Pluck the string"),
                                               FALSE, SFI_PARAM_GUI ":trigger:skip-undo"));
-  bse_object_class_add_param (object_class, "Decay", PARAM_NOTE_DECAY,
-			      sfi_pspec_real ("note_decay", "Note Decay",
-                                              "Note decay is the 'half-life' of the note's decay in seconds",
+  bse_object_class_add_param (object_class, _("Decay"), PARAM_NOTE_DECAY,
+			      sfi_pspec_real ("note_decay", _("Note Decay"),
+                                              _("Note decay is the 'half-life' of the note's decay in seconds"),
                                               0.4, 0.001, 4.0, 0.01,
                                               SFI_PARAM_STANDARD ":scale"));
-  bse_object_class_add_param (object_class, "Decay", PARAM_TENSION_DECAY,
-			      sfi_pspec_real ("tension_decay", "Tension Decay",
-                                              "Tension of the string",
+  bse_object_class_add_param (object_class, _("Decay"), PARAM_TENSION_DECAY,
+			      sfi_pspec_real ("tension_decay", _("Tension Decay"),
+                                              _("Tension of the string"),
                                               0.04, 0.001, 1.0, 0.01,
                                               SFI_PARAM_STANDARD ":scale"));
-  bse_object_class_add_param (object_class, "Flavour", PARAM_METALLIC_FACTOR,
-			      sfi_pspec_real ("metallic_factor", "Metallic Factor [%]",
-                                              "Metallicness of the string",
+  bse_object_class_add_param (object_class, _("Flavour"), PARAM_METALLIC_FACTOR,
+			      sfi_pspec_real ("metallic_factor", _("Metallic Factor [%]"),
+                                              _("Metallicness of the string"),
                                               16.0, 0.0, 100.0, 1,
                                               SFI_PARAM_STANDARD ":scale"));
-  bse_object_class_add_param (object_class, "Flavour", PARAM_SNAP_FACTOR,
-			      sfi_pspec_real ("snap_factor", "Snap Factor [%]",
-                                              "Snappiness of the string",
+  bse_object_class_add_param (object_class, _("Flavour"), PARAM_SNAP_FACTOR,
+			      sfi_pspec_real ("snap_factor", _("Snap Factor [%]"),
+                                              _("Snappiness of the string"),
                                               34.0, 0.0, 100.0, 1,
                                               SFI_PARAM_STANDARD ":scale"));
   
@@ -150,6 +167,7 @@ static void
 dav_xtal_strings_init (DavXtalStrings *self)
 {
   self->params.freq = BSE_KAMMER_FREQUENCY;
+  self->params.transpose_factor = 0.0; // updated when prepared
   self->params.trigger_vel = 1.0;
   self->params.note_decay = 0.4;
   self->params.tension_decay = 0.04;
@@ -181,10 +199,18 @@ dav_xtal_strings_set_property (GObject      *object,
       g_object_notify (G_OBJECT (self), "base_note");
       break;
     case PARAM_BASE_NOTE:
-      self->params.freq = bse_note_to_freq (sfi_value_get_note (value));
+      self->params.freq = bse_note_to_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), sfi_value_get_note (value));
       dav_xtal_strings_update_modules (self, FALSE);
       g_object_notify (G_OBJECT (self), "base_freq");
       break;
+    case PARAM_TRANSPOSE:
+      self->transpose = sfi_value_get_int (value);
+      dav_xtal_strings_update_modules (self, FALSE);
+      break;
+    case PARAM_FINE_TUNE:
+      self->params.fine_tune = sfi_value_get_int (value);
+      dav_xtal_strings_update_modules (self, FALSE);
+      break;
     case PARAM_TRIGGER_HIT:	/* GUI hack */
       dav_xtal_strings_update_modules (self, TRUE);
       break;
@@ -227,7 +253,13 @@ dav_xtal_strings_get_property (GObject    *object,
       sfi_value_set_real (value, self->params.freq);
       break;
     case PARAM_BASE_NOTE:
-      sfi_value_set_note (value, bse_note_from_freq (self->params.freq));
+      sfi_value_set_note (value, bse_note_from_freq (bse_item_current_musical_tuning (BSE_ITEM (self)), self->params.freq));
+      break;
+    case PARAM_TRANSPOSE:
+      sfi_value_set_int (value, self->transpose);
+      break;
+    case PARAM_FINE_TUNE:
+      sfi_value_set_int (value, self->params.fine_tune);
       break;
     case PARAM_TRIGGER_HIT:
       sfi_value_set_bool (value, FALSE);
@@ -253,6 +285,15 @@ dav_xtal_strings_get_property (GObject    *object,
     }
 }
 
+static void
+dav_xtal_prepare (BseSource *source)
+{
+  DavXtalStrings *self = DAV_XTAL_STRINGS (source);
+  self->params.transpose_factor = bse_transpose_factor (bse_source_prepared_musical_tuning (source), self->transpose);
+  /* chain parent class' handler */
+  BSE_SOURCE_CLASS (parent_class)->prepare (source);
+}
+
 static gfloat inline
 calc_factor (gfloat freq,
 	     gfloat t)
@@ -270,7 +311,7 @@ typedef struct {
   guint	               count;
   gfloat              *string;
   gfloat	       last_trigger_level;
-  gfloat	       last_trigger_freq;
+  gdouble	       last_transposed_trigger_freq;
   DavXtalStringsParams tparams;
 } XtalStringsModule;
 
@@ -278,13 +319,19 @@ typedef struct {
  */
 static inline void
 xmod_trigger (XtalStringsModule *xmod,
-	      gfloat             trigger_freq)
+	      gdouble            untransposed_trigger_freq)
 {
   guint i;
   guint pivot;
-  
+
+  /* calculate transposed trigger frequency; the "real frequency" that will
+   * be played, including detuning and transpose operations
+   */
+  gdouble trigger_freq = untransposed_trigger_freq;
+  trigger_freq *= xmod->tparams.transpose_factor;
+  trigger_freq *= bse_cent_factor (xmod->tparams.fine_tune);
   trigger_freq = CLAMP (trigger_freq, 27.5, 4000.0);
-  xmod->last_trigger_freq = trigger_freq;
+  xmod->last_transposed_trigger_freq = trigger_freq;
   
   xmod->pos = 0;
   xmod->count = 0;
@@ -325,7 +372,7 @@ xmod_process (BseModule *module,
   guint real_freq_256, actual_freq_256;
   guint i;
   
-  real_freq_256 = (int) (xmod->last_trigger_freq * 256);
+  real_freq_256 = (int) (xmod->last_transposed_trigger_freq * 256);
   actual_freq_256 = (int) (bse_engine_sample_freq() * 256. / xmod->size);
   
   if (BSE_MODULE_ISTREAM (module, DAV_XTAL_STRINGS_ICHANNEL_FREQ).connected)
@@ -339,7 +386,7 @@ xmod_process (BseModule *module,
       if (G_UNLIKELY (BSE_SIGNAL_RAISING_EDGE (last_trigger_level, trigger_in[i])))
       	{
 	  xmod_trigger (xmod, freq_in ? BSE_SIGNAL_TO_FREQ (freq_in[i]) : xmod->tparams.freq);
-	  real_freq_256 = (int) (xmod->last_trigger_freq * 256);
+	  real_freq_256 = (int) (xmod->last_transposed_trigger_freq * 256);
 	  actual_freq_256 = (int) (bse_engine_sample_freq() * 256. / xmod->size);
 	}
       last_trigger_level = trigger_in[i];
@@ -389,7 +436,7 @@ xmod_reset (BseModule *module)
   xmod->count = 0;
   xmod->a = 0.0;
   xmod->damping_factor = 0.0;
-  xmod->last_trigger_freq = 440.0;	/* just _some_ valid freq for the stepping */
+  xmod->last_transposed_trigger_freq = 440.0;	/* just _some_ valid freq for the stepping */
   xmod->last_trigger_level = 0;
 }
 
@@ -468,6 +515,7 @@ dav_xtal_strings_update_modules (DavXtalStrings *self,
        * test triggers from the GUI.
        */
       self->params.trigger_now = trigger_now;
+      self->params.transpose_factor = bse_transpose_factor (bse_source_prepared_musical_tuning (BSE_SOURCE (self)), self->transpose);
       bse_source_access_modules (BSE_SOURCE (self),
 				 xmod_access,
 				 g_memdup (&self->params, sizeof (self->params)),
