@@ -29,6 +29,7 @@
 #include <sfi/sfinote.h>
 #include <sfi/sfiparams.h>
 #include <sfi/sfiprimitives.h>
+#include <sfi/sfiring.h>
 /* #include <sfi/sfisclock.h> */
 #include <sfi/sfiserial.h>
 /* no bin-compat: #include <sfi/sfistore.h> */
@@ -37,6 +38,7 @@
 #include <sfi/sfiustore.h>
 #include <sfi/sfivalues.h>
 #include <sfi/sfivmarshal.h>
+#include <sfi/sfiwrapper.h>
 
 #endif /* __SFI_H__ */
 
