@@ -145,7 +145,7 @@ Options::parse (int   *argc_p,
       else if (check_arg (argc, argv, &i, "--permissive"))
         strict = false;
       else if (check_arg (argc, argv, &i, "--threshold", &opt_arg))
-        threshold = atof (opt_arg);
+        threshold = g_ascii_strtod (opt_arg, NULL);
     }
 
   /* resort argc/argv */
@@ -341,6 +341,10 @@ struct FeatureValue {
   FeatureValue (string name, Type type) : name (name), type (type)
   {
   }
+  virtual
+  ~FeatureValue()
+  {
+  }
   virtual GTokenType parse (GScanner *scanner) = 0;
   virtual string     printable_type() const = 0;
   /**
@@ -399,7 +403,9 @@ struct FeatureValueFile {
   vector<FeatureValue*> feature_values;
 
   GTokenType parseFeatureValue (GScanner *scanner);
-  void parse (const string& filename);
+  void       parse (const string& filename);
+
+  ~FeatureValueFile();
 };
 
 //------- FeatureValueNumber implementation --------
@@ -618,6 +624,12 @@ FeatureValueFile::parse (const string& filename)
     }
 }
 
+FeatureValueFile::~FeatureValueFile()
+{
+  for (vector<FeatureValue *>::iterator fvi = feature_values.begin(); fvi != feature_values.end(); fvi++)
+    delete *fvi;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -637,8 +649,8 @@ main (int argc, char **argv)
   if (file1.feature_values.size() != file2.feature_values.size())
     {
       g_printerr ("%s: can't compare files\n", options.program_name.c_str());
-      g_printerr ("  * file \"%s\" contains %ld feature values\n", file1.filename.c_str(), file1.feature_values.size());
-      g_printerr ("  * file \"%s\" contains %ld feature values\n", file2.filename.c_str(), file2.feature_values.size());
+      g_printerr ("  * file \"%s\" contains %zd feature values\n", file1.filename.c_str(), file1.feature_values.size());
+      g_printerr ("  * file \"%s\" contains %zd feature values\n", file2.filename.c_str(), file2.feature_values.size());
       exit (1);
     }
 
