@@ -18,8 +18,6 @@
  */
 #include "bseloopfuncs.h"
 #include <bse/gsldatacache.h>
-#include <bse/gslfilter.h>
-#include <complex.h>
 #include <string.h>
 #include <stdio.h>
 #include <math.h>
@@ -36,137 +34,6 @@ typedef struct {
   LoopEntry  entries[1];        /* flexible array */
 } LoopStack;
 
-/*
- * 0db ----------           __________
- *                         /
- *                        /
- *                       /
- * f1_level (dB) - _____/
- *
- *                      |   |
- *                      f1 f2
- *
- * @f1: high pass start frequency [0:PI] (SR = 2*PI)
- * @f2: high pass end frequency [0:PI] (SR = 2*PI)
- */
-
-static void
-fir_hp (const gfloat *src,
-	const guint   n_samples,
-	gfloat       *dest,
-	gdouble       f1,
-	gdouble       f1_level,
-	gdouble       f2)
-{
-  const guint iorder = 64;
-  double a[iorder + 1];
-
-  //const guint transfer_func_length = 64;
-  const guint transfer_func_length = 4;
-  double transfer_func_freqs[transfer_func_length];
-  double transfer_func_values[transfer_func_length];
-  float f1_level_factor = bse_db_to_factor (f1_level);
-
-  transfer_func_freqs[0]  = 0;
-  transfer_func_values[0] = f1_level_factor;
-
-  transfer_func_freqs[1]  = f1;
-  transfer_func_values[1] = f1_level_factor;
-
-  transfer_func_freqs[2]  = f2;
-  transfer_func_values[2] = 1.0; // 0 dB
-
-  transfer_func_freqs[3]  = PI;
-  transfer_func_values[3] = 1.0; // 0 dB
-
-  gsl_filter_fir_approx (iorder, a, transfer_func_length, transfer_func_freqs, transfer_func_values, TRUE);
-
-#if 0 // debugging
-  gfloat freq;
-  for (freq = 0; freq < PI; freq += 0.01)
-    {
-      complex z = cexp (I * freq);
-      complex r = 0;
-
-      guint i;
-      for (i = 0; i <= iorder; i++)
-	{
-	  r /= z;
-	  r += a[i];
-	}
-      printf ("%f %f\n", freq, cabs (r));
-    }
-
-  /* normalize */
-  gdouble norm = 0;
-  guint k;
-  for (k = 0; k <= iorder; k++)
-    norm += fabs (a[k]);
-
-  printf ("# norm = %f\n", norm);
-  for (k = 0; k <= iorder; k++)
-    a[k] /= norm;
-#endif
-
-  /* tiny FIR evaluation: not optimized for speed */
-  guint i, j;
-  for (i = 0; i < n_samples; i++)
-    {
-      gdouble accu = 0;
-      for (j = 0; j <= iorder; j++)
-	{
-	  GslLong p = i + j;
-	  p -= iorder / 2;
-
-	  if (p >= 0 && p < n_samples)
-	    accu += src[p];
-	}
-      dest[i] = accu;
-    }
-}
-
-GslDataHandle *gsl_loop_highpass_handle (GslDataHandle *src_handle,
-				         gdouble       freq1,
-				         gdouble       freq1_level_db,
-				         gdouble       freq2)
-{
-  g_return_val_if_fail (src_handle != NULL, NULL);
-
-  /* check out data handle */
-  if (gsl_data_handle_open (src_handle) != BSE_ERROR_NONE)
-    return NULL;
-
-  GslLong src_handle_n_values   = gsl_data_handle_n_values (src_handle);
-  GslLong src_handle_n_channels = gsl_data_handle_n_channels (src_handle);
-  GslLong src_handle_mix_freq   = gsl_data_handle_mix_freq (src_handle);
-  GslLong src_handle_osc_freq   = gsl_data_handle_osc_freq (src_handle);
-  gchar **src_handle_xinfos     = src_handle->setup.xinfos;
-
-  /* read input */
-  gfloat *src_values  = g_new (gfloat, src_handle_n_values);
-  GslLong i;
-  GslDataPeekBuffer pbuf = { +1, };
-  for (i = 0; i < src_handle_n_values; i++)
-    src_values[i] = gsl_data_handle_peek_value (src_handle, i, &pbuf);
-
-  /* apply fir filter to new memory buffer */
-  gfloat *dest_values = g_new (gfloat, src_handle_n_values);
-  fir_hp (src_values, src_handle_n_values, dest_values, freq1, freq1_level_db, freq2);
-  g_free (src_values);
-
-  /* create a mem handle with filtered data */
-  GslDataHandle *dest_handle = gsl_data_handle_new_mem (src_handle_n_channels,
-							32, // bit_depth: possibly increased by filtering
-						        src_handle_mix_freq,
-							src_handle_osc_freq,
-							src_handle_n_values,
-							dest_values,
-							g_free);
-
-  gsl_data_handle_close (src_handle);
-  return gsl_data_handle_new_add_xinfos (dest_handle, src_handle_xinfos);
-}
-
 static gdouble
 score_headloop (GslDataHandle *dhandle,
                 const gfloat  *ls, /* loop start */
